==> nut-17.5.tar.gz: nut-17.5/fltk/main.cc <==
/* main.cc */

/*
    NUT nutrition software 
    Copyright (C) 1996-2012 by Jim Jozwiak.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "food.h"
#include "meal.h"
#include "db.h"
#include "options.h"
#include "Nut.h"
#include <stdlib.h>
#include <string.h>
#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Tooltip.H>
#include <FL/x.H>
#include <X11/xpm.h>
#include "nut.xpm"

int main(int argc, char **argv)
{
food_root.next = NULL;
meal_root.next = NULL;
recipe_root.next = NULL;
theusual_root.next = NULL;
char title[60];
initializations();
int i = 1;
Fl::args(argc,argv,i);
if (argc > 1 && strncmp(argv[1],"-",1) != 0) 
 {
 make_filenames(argv[1]);
 sprintf(title,"NUT %s for %s [DB] %s",VERSIONQ,USDAVERSION,argv[1]);
 }
else 
 {
 make_filenames("");
 sprintf(title,"NUT %s for %s",VERSIONQ,USDAVERSION);
 }
if ( version(0) == MAJVERSION && version(1) == MINVERSION && read_food_db() )
 {
 read_meal_db();
 read_theusual_db();
 read_OPTIONS(0);
 }
else read_food_files();
if (version(0) != MAJVERSION || version(1) != MINVERSION) write_version();

FL_NORMAL_SIZE = fontsize();

#if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
int w = 850*FL_NORMAL_SIZE/14*FL_NORMAL_SIZE/(FL_NORMAL_SIZE-1), h = 1000 * w / 1618, margin = FL_NORMAL_SIZE/7;
#else                          
int w = 940*FL_NORMAL_SIZE/14*FL_NORMAL_SIZE/(FL_NORMAL_SIZE-1), h = 1000 * w / 1618, margin = FL_NORMAL_SIZE/7;
#endif

Fl_Double_Window *window = new Fl_Double_Window(w,h,title);
new Nut(margin, margin, w-2*margin, h-2*margin);
window->end();
window->color(FL_WHITE);
fl_open_display();

#if !defined(WIN32) && !defined(__APPLE__)
Pixmap p, mask;

XpmCreatePixmapFromData(fl_display, DefaultRootWindow(fl_display), (char **)nut, &p, &mask, NULL);

window->icon((char *)p);
#endif

window->show(argc, argv);
return Fl::run();
}

==> nut-17.7.tar.gz: nut-17.7/fltk/main.cc <==
/* main.cc */

/*
    NUT nutrition software 
    Copyright (C) 1996-2012 by Jim Jozwiak.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "food.h"
#include "meal.h"
#include "db.h"
#include "options.h"
#include "Nut.h"
#include <stdlib.h>
#include <string.h>
#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Tooltip.H>

int main(int argc, char **argv)
{
food_root.next = NULL;
meal_root.next = NULL;
recipe_root.next = NULL;
theusual_root.next = NULL;
char title[60];
initializations();
int i = 1;
Fl::args(argc,argv,i);
if (argc > 1 && strncmp(argv[1],"-",1) != 0) 
 {
 make_filenames(argv[1]);
 sprintf(title,"NUT %s for %s [DB] %s",VERSIONQ,USDAVERSION,argv[1]);
 }
else 
 {
 make_filenames("");
 sprintf(title,"NUT %s for %s",VERSIONQ,USDAVERSION);
 }
if ( version(0) == MAJVERSION && version(1) == MINVERSION && read_food_db() )
 {
 read_meal_db();
 read_theusual_db();
 read_OPTIONS(0);
 }
else read_food_files();
if (version(0) != MAJVERSION || version(1) != MINVERSION) write_version();

FL_NORMAL_SIZE = fontsize();
Fl_Tooltip::size(FL_NORMAL_SIZE);

#if FL_MAJOR_VERSION == 1 && FL_MINOR_VERSION == 1
int w = 850*FL_NORMAL_SIZE/14*FL_NORMAL_SIZE/(FL_NORMAL_SIZE-1), h = 1000 * w / 1618, margin = FL_NORMAL_SIZE/7;
#else                          
int w = 940*FL_NORMAL_SIZE/14*FL_NORMAL_SIZE/(FL_NORMAL_SIZE-1), h = 1000 * w / 1618, margin = FL_NORMAL_SIZE/7;
#endif

Fl_Double_Window *window = new Fl_Double_Window(w,h,title);
new Nut(margin, margin, w-2*margin, h-2*margin);
window->end();
window->color(FL_WHITE);
window->show(argc, argv);
return Fl::run();
}
